# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-04-09 09:27
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('howl', '0006_auto_20160409_1102'),
    ]

    operations = [
        migrations.AlterField(
            model_name='observer',
            name='value',
            field=models.FloatField(verbose_name='Value'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-01-01 07:30
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('howl', '0007_auto_20160409_1127'),
    ]

    operations = [
        migrations.AlterField(
            model_name='observer',
            name='operator',
            field=models.CharField(choices=[('EqualOperator', 'Equals'), ('GreaterThanOperator', 'Greater than'), ('LowerThanOperator', 'Lower than'), ('MyOperator', 'My +2')], max_length=32, verbose_name='Operator type'),
        ),
    ]



from django.contrib import admin

from .models import Alert, Observer


@admin.register(Observer)
class ObserverAdmin(admin.ModelAdmin):
    list_display = ('name', 'operator', 'value')


@admin.register(Alert)
class AlertAdmin(admin.ModelAdmin):
    list_display = ('identifier', 'timestamp', 'value', 'state')
    list_filter = ('state',)
